@@ -1,7 +1,7 @@
 """Contains multiple classes for file conversions. These include:
-    * txtconvert
-    * imgconvert
-    * sheetconvert
+    >>> txtconvert
+    >>> imgconvert
+    >>> sheetconvert
 """
 
 import os
@@ -21,138 +21,179 @@ from xlsxwriter.workbook import Workbook
 import warnings
 warnings.filterwarnings("ignore")
 
-def _format_check(*args, fmtype):
-    """Checks for variable/s type. Helper to _typecheck.
+class _basehelpers:
+    def __init__(self, *args, fmtype):
+        """Constructor class containing the following functions:
 
-    Args:
-        * `__input__` ([type]: any): Input variable.
+        Includes:
+        >>> _format_check()
+        >>> _pathcheck()
+
+        * `*args` ([type]: any): Input variable/s to check.
         * `fmtype` ([type]: any): Type of variable to check.
+        """
 
-    Raises:
-        TypeError: When type of variable is != to `fmtype`
-    """
-    for n in args:
-        a = type(n).__name__
-        if not isinstance(n, fmtype):
-            raise TypeError(f'{n} must be a string not a type {a}')
+        self.args = args
+        self.fmtype = fmtype
 
-def typecheck(__object__):
-    """Check whether object is a directory.
+    def _format_check(self):
+        """Checks for variable/s type. Helper to inpchecker.
+        Raises:
+            TypeError: When type of variable is != to `fmtype`
+        """
+        for n in self.args:
+            a = type(n).__name__
+            if not isinstance(n, self.fmtype):
+                raise TypeError(f'{n} must be of type {self.fmtype.__name__} not a type {a}')
 
-    Args:
-        * `__object__` ([type]: str): Path of file/directory.
+    def _pathcheck(self):
+        """Check if input file or directory exists.
 
-    Raises:
-        [type]: `TypeError` if __object__ is not a string.
+        Args:
+            * `args` ([type]: `str`): input file or directory.
 
-    Returns:
-        [type]: `bool`: True if directory, False if not.
-    """
+        Returns:
+            [type]: `FileNotFoundError`: FileNotFoundError is returned when object path doesn't exist. If it does returns `None`.
+        """
 
-    _format_check(__object__, fmtype = str)
-    return os.path.isdir(__object__)
+        for i in self.args:
+            inp = ''.join(i)
+            x = Path(inp)
+            if not x.exists():
+                raise FileNotFoundError(errno.ENOENT, os.strerror(errno.ENOENT), inp)
 
-def outpath(dinput, flinput):
-    """Generate output file path.
+class _inpchecker:
+    def __init__(self, inp1, inp2, ftype):
+        """Runs all the functions of the _basehelpers class. 
 
-    Args:
-        * `dinput` ([type]: `str`): Input directory.
-        * `flinput` ([type]: `str`): Input file. Must not be the TextIOWrapper!!!
+        Args:
+            * `inp1` ([type]: `str`): Input file/directory.
+            * `inp2` ([type]: `str`): Output file/directory.
+            * `ftype` ([type]: `str`): Type of file to check for.
+        """
 
-    Returns:
-        [type]: `str`: Output path.
-    """
+        self.inp1 = inp1
+        self.inp2 = inp2
+        self.ftype = ftype
 
-    file_name = os.path.splitext(os.path.basename(flinput))[0]
-    subdir = str(os.path.join(dinput, file_name))
+    def initchecker(self):
+        basehelpers = _basehelpers(self.inp1, self.inp2, self.ftype)
+        basehelpers._format_check()  # Check if objects are of ftype.
+        basehelpers._pathcheck() # Check for the existance of the input paths.
 
-    return subdir
+class _helpers():
 
-def compatibility(__inpobj__, __compat__):
-    """Check for file compatibility. 
+    @staticmethod
+    def sminp(inp, outext):
+        """Check if input file has the same extension as the requested extension.
 
-    Removes elements from an object (`__inpobj__`) that don't contain substrings
-    equal to any of the substring of another list (`__compat__`).
+        Args:
+            * `inp` ([type]: str): Input file
+            * `outext` ([type]:str): Requested file type.
 
-    Arg:
-        * `__inpobj__` ([type]: `str`): input directory.
+        Returns:
+            [type]: `TypeError` if its the same.
+        """
 
-        * `__compt__` ([type]: `lst`): List of compatible file types.
+        f, f_ext = os.path.splitext(inp)    # Get file extension as str.
+        if f_ext == outext:
+            return TypeError(f'{f} file is already a {outext} file')
 
-    Raises:
-        * `OSError`: when no compatible files are given.
+    @staticmethod
+    def outpath(dinput, flinput):
+            """Generate output file path.
 
-    Returns:
-        [type]: `lst`: a list containing elements that contain substrings equal to the elements of the `compat` list."""
+            Args:
+                * `dinput` ([type]: `str`): Input directory.
+                * `flinput` ([type]: `str`): Input file. Must not be the TextIOWrapper!!!
 
-    contents = os.listdir(__inpobj__)  # List dir contents.
+            Returns:
+                [type]: `str`: Output path.
+            """
 
-    contents[:] = [fl for fl in contents if any(ext in fl for ext in __compat__)]   # Removes elements in directory contents that
-                                                                                    # don't contain the compatible extensions.
+            file_name = os.path.splitext(os.path.basename(flinput))[0]
+            subdir = str(os.path.join(dinput, file_name))
 
-    if not contents:
-        raise OSError('No compatible files found')
+            return subdir
 
-    return list(contents)
+    @staticmethod
+    def compatibility(__inpobj__, __compat__):
+        """Check for file compatibility. 
 
-def typencd(__inpobj__):
-    """Find encoding type of file.
+        Removes elements from an object (`__inpobj__`) that don't contain substrings
+        equal to any of the substring of another list (`__compat__`).
 
-    Args:
-        * `__inpobj__` ([type]: `str`): Input file.
+        Arg:
+            * `__inpobj__` ([type]: `str`): input directory.
 
-    Returns:
-        [type]: `str`: Type of encoding.
-    """
+            * `__compt__` ([type]: `lst`): List of compatible file types.
 
-    rawdata = open(__inpobj__, 'rb').read()
-    result = chardet.detect(rawdata)
-    charenc = result['encoding']
+        Raises:
+            * `OSError`: when no compatible files are given.
 
-    return str(charenc)
+        Returns:
+            [type]: `lst`: a list containing elements that contain substrings equal to the elements of the `compat` list."""
 
-def _pathcheck(*args):
-    """Check if input file or directory exists.
+        contents = os.listdir(__inpobj__)  # List dir contents.
 
-    Args:
-        * `args` ([type]: `str`): input file or directory.
+        contents[:] = [fl for fl in contents if any(ext in fl for ext in __compat__)]   # Removes elements in directory contents that
+                                                                                        # don't contain the compatible extensions.
 
-    Returns:
-        [type]: `FileNotFoundError`: FileNotFoundError is returned when object path doesn't exist. If it does returns `None`.
-    """
+        if not contents:
+            raise OSError('No compatible files found')
 
-    for i in args:
-        inp = ''.join(i)
-        x = Path(inp)
-        if not x.exists():
-            raise FileNotFoundError(errno.ENOENT, os.strerror(errno.ENOENT), inp)
+        return list(contents)
 
-def sminp(inp, outext):
-    """Check if input file has the same extension as the requested extension.
+    @staticmethod
+    def typencd(__inpobj__):
+        """Find encoding type of file.
 
-    Args:
-        * `inp` ([type]: str): Input file
-        * `outext` ([type]:str): Requested file type.
+        Args:
+            * `__inpobj__` ([type]: `str`): Input file.
 
-    Returns:
-        [type]: `TypeError` if its the same.
-    """
+        Returns:
+            [type]: `str`: Type of encoding.
+        """
 
-    f, f_ext = os.path.splitext(inp)    # Get file extension as str.
-    if f_ext == outext:
-        return TypeError(f'{f} file is already a {outext} file')
+        rawdata = open(__inpobj__, 'rb').read()
+        result = chardet.detect(rawdata)
+        charenc = result['encoding']
 
-def inpchecker(inp1, inp2, ftype):
-    """Wrapper for _format_check and _pathcheck. Checks the user inputs.
+        return str(charenc)
 
-    Args:
-        * `inp1` ([type]: any): First input.
-        * `inp2` ([type]: any): Second input.
-        * `ftype` ([type]: any): Variable format type.
-    """
-    _format_check(inp1, inp2, fmtype = ftype)  # Check if objects are of ftype.
-    _pathcheck(inp1, inp2) # Check for the existance of the input paths.
+    @staticmethod
+    def typecheck(__object__):
+        """Check whether object is a directory.
 
+        Args:
+            * `__object__` ([type]: str): Path of file/directory.
+
+        Raises:
+            [type]: `TypeError` if __object__ is not a string.
+
+        Returns:
+            [type]: `bool`: True if directory, False if not.
+        """
+
+        _basehelpers(__object__, fmtype = str)._format_check()
+        return os.path.isdir(__object__)
+
+    @staticmethod
+    def outpath(dinput, flinput):
+        """Generate output file path.
+
+        Args:
+            * `dinput` ([type]: `str`): Input directory.
+            * `flinput` ([type]: `str`): Input file. Must not be the TextIOWrapper!!!
+
+        Returns:
+            [type]: `str`: Output path.
+        """
+
+        file_name = os.path.splitext(os.path.basename(flinput))[0]
+        subdir = str(os.path.join(dinput, file_name))
+
+        return subdir
 
 class txtconvert:
     """Holds function to convert .txt and other text document files into .docx format. Conversions include
@@ -168,7 +209,7 @@ class txtconvert:
 
     Example with txt_docx():
 
-    >>> from convert.flconverters import txtconvert
+    >>> from flconverters import txtconvert
 
     >>> txtconv = txtconvert(__file__ = path/to/file/, d = path/to/output/directory)
 
@@ -178,9 +219,9 @@ class txtconvert:
     disable: bool
     __file__: str
 
-    def __init__(self, __file__, __disable__ = False, __d__ = os.getcwd()):
+    def __init__(self, __file__, disable = False, __d__ = os.getcwd()):
         self.__file__ = __file__
-        self.disable = __disable__
+        self.disable = disable
         self.__d__ = __d__
 
         # Check class arguments for errors.
@@ -192,8 +233,8 @@ class txtconvert:
         if not ((os.path.isdir(__file__)) or os.path.isfile(__file__)):
             raise ValueError('__file__ must be a path to a file or directory.')
 
-        if not isinstance(__disable__, bool):
-            raise ValueError(f'__disable__ must be Boolean, not of Type: {(type(__disable__)).__name__}.')
+        if not isinstance(disable, bool):
+            raise ValueError(f'disable must be Boolean, not of Type: {(type(disable)).__name__}.')
 
         if not os.path.isdir(__d__):
             raise ValueError(f'__d__ must be a directory and a Type: string, not equal to {__d__} and of Type: {(type(__d__)).__name__}.')
@@ -214,15 +255,14 @@ class txtconvert:
         or if input directory does not contain any supported file format.
         """
 
-        inpchecker(inp1 = self.__file__, inp2 = self.__d__, ftype = str)   # Check if objects are strings and 
-                                                                            # for the existance of the input paths.
+        _inpchecker(inp1 = self.__file__, inp2 = self.__d__, ftype = str)  # Check if objects are strings and for the existance of the input paths.
 
-        type_check = typecheck(__object__ = self.__file__)
+        type_check = _helpers.typecheck(__object__ = self.__file__)
         extensions = [".txt", ".log", ".ini"] # Supported Text Document file extensions.
 
         # Check if __file__ instance is a parent/child directory.
         if type_check == True:
-            dir_contents = compatibility(__inpobj__ = self.__file__, __compat__ = extensions)
+            dir_contents = _helpers.compatibility(__inpobj__ = self.__file__, __compat__ = extensions)
             checktxt = True
             checkfl = None  # __file__ instance is not a single file.
         else:
@@ -235,28 +275,28 @@ class txtconvert:
             for f in tqdm(dir_contents, desc = 'Converting %i files to .docx format' %(len(dir_contents)), unit = ' Files', disable = self.disable):  # Iterate over all the entries.
                 doc = Document() 
                 flpath = os.path.join(self.__file__, f)
-                enc = typencd(__inpobj__ = flpath)    
+                enc = _helpers.typencd(__inpobj__ = flpath)    
                 with open(flpath, 'r', encoding = enc) as inf:    
                     line = inf.read()
                     doc.add_paragraph(line)
-                    doc.save(outpath(dinput = self.__d__, flinput = flpath) + ".docx") # full path of output .docx file to save.
+                    doc.save(_helpers.outpath(dinput = self.__d__, flinput = flpath) + ".docx") # full path of output .docx file to save.
 
         # __file__ instance is *not* a parent/child directory, but is a .txt file.
         elif type_check == False and checkfl == True:
             print(f'Converting {self.__file__} into a .docx format.')
             doc = Document()    
-            enc = typencd(__inpobj__ = self.__file__)
+            enc = _helpers.typencd(__inpobj__ = self.__file__)
             with open(self.__file__, 'r', encoding = enc) as inf:  
                 line = inf.read()
                 doc.add_paragraph(line)
-                output = doc.save(outpath(dinput = self.__d__, flinput = self.__file__) + ".docx") # full path of output .docx file to save.
+                output = doc.save(_helpers.outpath(dinput = self.__d__, flinput = self.__file__) + ".docx") # full path of output .docx file to save.
             print(f'Conversion complete! New file is saved in {output}.')
 
         # __file__ instance is neither a parent/child directory or a file in .txt format. 
         else:
             raise TypeError(f"{self.__file__} must either be a directory that contains at least 1 compatible file or an individual compatible file.")
 
-class imgconvert():
+class imgconvert:
     """Holds multiple functions to convert image files into other file formats. Conversions include:
        * image to pdf.
        * image to base64 text file (UTF-8 encryption).
@@ -265,7 +305,7 @@ class imgconvert():
 
     Args:
         * `__file__` ([type]: `str`): Input file/directory.
-        * `__disable__` ([type]: `bool`): Argument to disable or enable the stdout of the tqdm progress bar.
+        * `disable` ([type]: `bool`): Argument to disable or enable the stdout of the tqdm progress bar.
         * `__d__` ([type]: `str`): Output directory. Default is the current working directory.
 
     Functions:  
@@ -278,7 +318,7 @@ class imgconvert():
                 >>> img_format(format)
 
     Example with img_pdf:
-                >>> from convert.flconverters import imgconvert
+                >>> from flconverters import imgconvert
                 
                 >>> imgconv = imgconvert(__file__ = path/to/file/or_list_of_file_paths, d = path/to/output/directory)  
                 
@@ -292,9 +332,9 @@ class imgconvert():
     pdf: str
     format: str
 
-    def __init__(self, __file__, __disable__ = False, __d__ = os.getcwd()):
+    def __init__(self, __file__, disable = False, __d__ = os.getcwd()):
         self.__file__ = __file__
-        self.disable = __disable__
+        self.disable = disable
         self.__d__ = __d__
 
         # Check class arguments for errors.
@@ -306,8 +346,8 @@ class imgconvert():
         if not ((os.path.isdir(__file__)) or os.path.isfile(__file__)):
             raise ValueError('__file__ must be a path to a file or directory.')
 
-        if not isinstance(__disable__, bool):
-            raise ValueError(f'__disable__ must be Boolean, not of Type: {(type(__disable__)).__name__}.')
+        if not isinstance(disable, bool):
+            raise ValueError(f'disable must be Boolean, not of Type: {(type(disable)).__name__}.')
 
         if not os.path.isdir(__d__):
             raise ValueError(f'__d__ must be a directory and a Type: string, not equal to {__d__} and of Type: {(type(__d__)).__name__}.')
@@ -376,6 +416,8 @@ class imgconvert():
 
         if __kp__ == True and subdir == flname and __bw__ == "":
             bwn = "bnr"
+        else:
+            bwn = ""
 
         img_bw = str(subdir + bwn + ext)
         cv2.imwrite(img_bw, img_binary)
@@ -395,20 +437,19 @@ class imgconvert():
         or if input directory does not contain any supported file format.
         """
 
-        inpchecker(inp1 = self.__file__, inp2 = self.__d__, ftype = str)   # Check if objects are strings and 
-                                                                            # for the existance of the input paths.
+        _inpchecker(inp1 = self.__file__, inp2 = self.__d__, ftype = str)  # Check if objects are strings and for the existance of the input paths.
 
-        type_check = typecheck(__object__ = self.__file__)
+        type_check = _helpers.typecheck(__object__ = self.__file__)
 
         # file formats supported
-        extensions = (".jpeg", ".jpg", ".png", ".tif", ".tiff", ".hdr", ".pic", ".sr", ".ras", ".pfm", "pbm", 
+        extensions = (".jpeg", ".jpg", ".png", ".tif", ".tiff", ".nef" ".hdr", ".pic", ".sr", ".ras", ".pfm", "pbm", 
                     ".pgm", ".ppm", ".pxm", ".pnm", ".webp", ".jp2", ".jpe", ".bmp", ".dib",
                     ".JPEG",  ".JPG", ".PNG", ".TIF", ".TIFF", ".HDR", ".PIC", ".SR", ".RAS", ".PFM", "PBM", 
-                    ".PGM", ".PPM", ".PXM", ".PNM", ".WEBP", ".JP2", ".JPE", ".BMP", ".DIB")
+                    ".PGM", ".PPM", ".PXM", ".PNM", ".WEBP", ".JP2", ".JPE", ".BMP", ".DIB", ".NEF")
 
         # Check if __file__ instance is a parent/child directory.
         if type_check == True:
-            dir_contents = compatibility(__inpobj__ = self.__file__, __compat__ = extensions)
+            dir_contents = _helpers.compatibility(__inpobj__ = self.__file__, __compat__ = extensions)
             checkfl = None  # __file__ instance is not a single file.
         else:
             type_check = False
@@ -435,9 +476,8 @@ class imgconvert():
         """Encode an image file or directory with images to base64 (`UTF-8`) and save it as `.txt`
         """
 
-        inpchecker(inp1 = self.__file__, inp2 = self.__d__, ftype = str)   # Check if objects are strings and 
-                                                                            # for the existance of the input paths.
-        type_check = typecheck(__object__ = self.__file__)
+        _inpchecker(inp1 = self.__file__, inp2 = self.__d__, ftype = str)  # Check if objects are strings and for the existance of the input paths.
+        type_check = _helpers.typecheck(__object__ = self.__file__)
 
         # Supported image extensions for conversion to base64.
         supp_ext = ( '.dng', '.raw', '.cr2', '.crw', '.erf', '.raf', '.tif', '.tiff', '.kdc', '.dcr', '.mos', '.mef', '.nef', '.orf', '.rw2', '.pef', 
@@ -450,7 +490,7 @@ class imgconvert():
 
         # __file__ is a parent/child directory.
         if type_check == True:
-            dir_contents = compatibility(__inpobj__ = self.__file__, __compat__ = supp_ext)
+            dir_contents = _helpers.compatibility(__inpobj__ = self.__file__, __compat__ = supp_ext)
             for f in tqdm(dir_contents, desc = 'Converting %i files to base64 format' %len(dir_contents) , unit=' Files', disable = self.disable):  # Iterate over all the entries
                 flinp = os.path.join(self.__file__, f)
                 self._64conv(__inp__ = flinp, __outd__ = self.__d__) 
@@ -472,18 +512,17 @@ class imgconvert():
         * `.x3f`, `.srw`, `.srf`, `.sr2`, `.arw`, `.mdc`, `.bmp`, `.mrw`
         """
 
-        inpchecker(inp1 = self.__file__, inp2 = self.__d__, ftype = str)   # Check if objects are strings and 
-                                                                            # for the existance of the input paths.
+        _inpchecker(inp1 = self.__file__, inp2 = self.__d__, ftype = str)  # Check if objects are strings and for the existance of the input paths.
 
         supp_ext = ( '.dng', '.raw', '.crw', '.erf', '.raf', '.tif', '.tiff', '.kdc', '.dcr', '.mos', '.mef', '.nef', '.orf', '.rw2', '.pef', 
                 '.x3f', '.srw', '.srf', '.sr2', '.mdc', '.bmp', '.mrw', '.DNG', '.RAW', '.CRW', '.ERF', '.RAF', '.TIF', '.TIFF', 
                 '.KDC', '.DCR', '.MOS', '.MEF', '.NEF', '.ORF', '.RW2', '.BMP', '.PEF', '.X3F', '.SRW', '.SRF', '.SR2', '.MDC', '.MRW' ,
                 '.jpeg', '.png', '.jpg', '.JPEG', '.PNG', '.JPG')
-        type_check = typecheck(__object__ = self.__file__)
+        type_check = _helpers.typecheck(__object__ = self.__file__)
 
         # __file__ is a parent/child directory.
         if type_check == True:
-            dir_contents = compatibility(__inpobj__ = self.__file__, __compat__ = supp_ext)
+            dir_contents = _helpers.compatibility(__inpobj__ = self.__file__, __compat__ = supp_ext)
             for f in tqdm(dir_contents, desc = 'Converting %i files to .pdf format' %len(dir_contents) , unit=' Files', disable = self.disable):  # Iterate over all the entries
                 flinp = os.path.join(self.__file__, f)
                 self._pdfconv(__inp__ = flinp, __outd__ = self.__d__)
@@ -512,8 +551,7 @@ class imgconvert():
         * .x3f, .srw, .srf, .sr2, .arw, .mdc, .bmp, .mrw
         """
 
-        inpchecker(inp1 = self.__file__, inp2 = self.__d__, ftype = str)   # Check if objects are strings and 
-                                                                            # for the existance of the input paths.
+        _inpchecker(inp1 = self.__file__, inp2 = self.__d__, ftype = str)  # Check if objects are strings and for the existance of the input paths.
 
         ext = ( '.dng', '.raw', '.cr2', '.png', '.jpeg', '.jpg', '.crw', '.erf', '.raf', '.tif', '.tiff', '.kdc', '.dcr', '.mos', '.mef', '.nef', '.orf', '.rw2', '.pef', 
                 '.x3f', '.srw', '.srf', '.sr2', '.arw', '.mdc', '.bmp', '.mrw', '.DNG', '.RAW', '.CR2', '.CRW', '.ERF', '.RAF', '.TIF', '.TIFF', 
@@ -579,11 +617,11 @@ class imgconvert():
 
             return subdir, flpath
 
-        type_check = typecheck(__object__ = self.__file__)
+        type_check = _helpers.typecheck(__object__ = self.__file__)
 
         # __file__ is a parent/child directory.
         if type_check == True:
-            dir_contents = compatibility(__inpobj__ = self.__file__, __compat__ = ext)
+            dir_contents = _helpers.compatibility(__inpobj__ = self.__file__, __compat__ = ext)
             for f in tqdm(dir_contents, desc = 'Converting %i files to %s format' %(len(dir_contents),format) , unit=' Files', disable = self.disable):  # Iterate over all the entries
                 fl_handler = _loop_flobj(obj = self.__file__, fl = f, adir = self.__d__)
                 var, obj_ext = os.path.splitext(f)    # var is placeholder, obj_ext is the input file extension.
@@ -598,21 +636,21 @@ class imgconvert():
 
         # __file__ is not a parent/child directory, desired format is JPEG.
         elif type_check == False and self.__file__.endswith(ext) and format == ".jpeg":
-            subdir = outpath(dinput = self.__d__, flinput = self.__file__)
+            subdir = _helpers.outpath(dinput = self.__d__, flinput = self.__file__)
             print(f'Converting {self.__file__} into .jpeg format.')        
             output = _tojpg(flname = subdir, infl = self.__file__)
             print(f'Conversion complete! New file is saved in {output}.')  
         
         # __file__ is not a parent/child directory, desired format is JPG.
         elif type_check == False and self.__file__.endswith(ext) and format == ".jpg":        
-            subdir = outpath(dinput = self.__d__, flinput = self.__file__)
+            subdir = _helpers.outpath(dinput = self.__d__, flinput = self.__file__)
             print(f'Converting {self.__file__} into .jpg format.') 
             output = _tojpg(flname = subdir, infl = self.__file__)
             print(f'Conversion complete! New file is saved in {output}.')  
 
         # __file__ is not a parent/child directory, desired format is PNG.
         elif type_check == False and self.__file__.endswith(ext) and format == ".png":        
-            subdir = outpath(dinput = self.__d__, flinput = self.__file__)
+            subdir = _helpers.outpath(dinput = self.__d__, flinput = self.__file__)
             print(f'Converting {self.__file__} into .png format.') 
             output = _topng(flname = subdir, infl = self.__file__)
             print(f'Conversion complete! New file is saved in {output}.')
@@ -622,7 +660,7 @@ class imgconvert():
             var, obj_ext = os.path.splitext(self.__file__)    # var is placeholder, obj_ext is the input file extension.
             raise TypeError(f'{obj_ext} file format of {self.__file__} input file is not supported.')
 
-class sheetconvert():
+class sheetconvert:
     """Allows for the conversion of a single or multiple spreadsheet files
     (.xlsx, .csv, .tsv) into .xlsx, .csv or .tsv.
 
@@ -635,9 +673,9 @@ class sheetconvert():
         >>> convertsh(totype)
     
     Example:
-        >>> from convert.flconverters import sheetconvert
+        >>> from flconverters import sheetconvert
         >>> a = sheetconvert(__file__ = 'path/to/file/or/dir', __d__ = 'path/to/output/dir')
-        >>> a.convertsh(totype = '.csv')
+        >>> a.convertsh(totype = '.csv or .xlsx or .tsv')
     """
 
     __file__: str
@@ -647,9 +685,9 @@ class sheetconvert():
     csv_file: str
     xlsx_name: str 
 
-    def __init__(self, __file__, __disable__ = False, __d__ = os.getcwd()):
+    def __init__(self, __file__, disable = False, __d__ = os.getcwd()):
         self.__file__ = __file__
-        self.disable = __disable__
+        self.disable = disable
         self.__d__ = __d__
 
         # Check class arguments for errors.
@@ -661,8 +699,8 @@ class sheetconvert():
         if not ((os.path.isdir(__file__)) or os.path.isfile(__file__)):
             raise ValueError('__file__ must be a path to a file or directory.')
 
-        if not isinstance(__disable__, bool):
-            raise ValueError(f'__disable__ must be Boolean, not of Type: {(type(__disable__)).__name__}.')
+        if not isinstance(disable, bool):
+            raise ValueError(f'disable must be Boolean, not of Type: {(type(disable)).__name__}.')
 
         if not os.path.isdir(__d__):
             raise ValueError(f'__d__ must be a directory and a Type: string, not equal to {__d__} and of Type: {(type(__d__)).__name__}.')
@@ -828,7 +866,7 @@ class sheetconvert():
 
         return output
 
-    def convertsh(self, fromtype, totype):
+    def convertsh(self, totype, fromtype = None):
         """Convert an `.xlsx`/`.csv`/`.tsv` file to either `.xlsx` or `.csv` or `.tsv`. If the file is
         directory, it converts all the files in the directory that are `.xlsx`, `.tsv` and `.csv`.
 
@@ -837,32 +875,34 @@ class sheetconvert():
             * `totype` ([type]:`str`): type of converion, e.g: '.csv', '.xlsx', '.tsv'.
         """
 
-        inpchecker(inp1 = self.__file__, inp2 = self.__d__, ftype = str)   # Check if objects are strings and 
-                                                                            # for the existance of the input paths.
+        _inpchecker(inp1 = self.__file__, inp2 = self.__d__, ftype = str)  # Check if objects are strings and for the existance of the input paths.
 
         supp_ext = ( ".xlsx", ".csv", ".tsv" )  # Spreadsheet supported extenstions.
 
-        if not fromtype in supp_ext:
-            raise TypeError(f"{fromtype} file extension not supported")
-
-        if not totype in supp_ext:
-            raise TypeError(f"{totype} file extension not supported")
-
-        type_check = typecheck(__object__ = self.__file__)
-
+        type_check = _helpers.typecheck(__object__ = self.__file__)
+        
         # __file__ is a parent/child directory.
         if type_check == True:
-            dir_contents = compatibility(__inpobj__ = self.__file__, __compat__ = supp_ext)
-            dir_contents[:] = [fl for fl in dir_contents if any(ext not in fl for ext in totype)]   # Removes elements in directory that contain the selected extension.
-            dir_contents[:] = [fl for fl in dir_contents if any(ext in fl for ext in fromtype)]   # Removes elements in directory that don't contain the selected extension.
-            for f in tqdm(dir_contents, desc = 'Converting %i files to %s format' %(len(dir_contents),totype) , unit=' Files', disable = self.disable):  # Iterate over all the entries
-                build_fpath = os.path.join(self.__file__, f)
-                self._conversion_method(__inp__ = build_fpath, outdir = self.__d__, typeinp = totype)
+            if fromtype != None:
+                if not fromtype in supp_ext:
+                    raise TypeError(f"{fromtype} file extension not supported")
+                if not totype in supp_ext:
+                    raise TypeError(f"{totype} file extension not supported")
+
+                # Conversion is initiated here.
+                dir_contents = _helpers.compatibility(__inpobj__ = self.__file__, __compat__ = supp_ext)
+                dir_contents[:] = [fl for fl in dir_contents if any(ext not in fl for ext in totype)]   # Removes elements in directory that contain the selected extension.
+                dir_contents[:] = [fl for fl in dir_contents if any(ext in fl for ext in fromtype)]   # Removes elements in directory that don't contain the selected extension.
+                for f in tqdm(dir_contents, desc = 'Converting %i files to %s format' %(len(dir_contents),totype) , unit=' Files', disable = self.disable):  # Iterate over all the entries
+                    build_fpath = os.path.join(self.__file__, f)
+                    self._conversion_method(__inp__ = build_fpath, outdir = self.__d__, typeinp = totype)
+            elif isinstance(fromtype, None):
+                raise TypeError(f"Input argument __file__ is a directory but fromtype argument is None. Please specify fromtype argument.")
 
         # __file__ is not a parent/child directory.
-        else:
-            sminp(self.__file__, totype)   # Check if input file extension and 
-                                            # totype extension are the same.
-            print(f'Converting {self.__file__} into {totype} format.') 
+        elif type_check == False:
+            _helpers.sminp(self.__file__, totype)   # Check if input file extension and 
+                                                    # totype extension are the same.
+            print(f'Converting {self.__file__} into {totype} format...') 
             output = self._conversion_method(__inp__ = self.__file__, outdir = self.__d__, typeinp = totype)
-            print(f'Conversion complete! New file is saved in {output}.')
+            print(f'Conversion complete! New file is saved in {output}.')
\ No newline at end of file
